@@ -7,10 +7,7 @@ class RegionConfiguration(object):
     class abstracts all region/partition specific configuration.
     """
 
-    partitions = {
-        "govcloud": "aws-us-gov",
-        "china": "aws-cn"
-    }
+    partitions = {"govcloud": "aws-us-gov", "china": "aws-cn"}
 
     @classmethod
     def is_apigw_edge_configuration_supported(cls):
@@ -21,7 +18,4 @@ class RegionConfiguration(object):
         :return: True, if API Gateway does not support Edge configuration
         """
 
-        return ArnGenerator.get_partition_name() not in [
-            cls.partitions["govcloud"],
-            cls.partitions["china"]
-        ]
+        return ArnGenerator.get_partition_name() not in [cls.partitions["govcloud"], cls.partitions["china"]]
